from PythonPals.Button import button
from PythonPals import questions
from PythonPals.questions import *
from PythonPals import player
